@@ -2,6 +2,7 @@ import datetime
 
 from django.http import HttpResponse
 from django.utils.crypto import get_random_string
+from django.utils.encoding import force_text
 
 from .compat import etree
 from .compat import get_username
@@ -70,7 +71,7 @@ class ValidationResponse(CasResponseBase):
                 attribute_set = etree.SubElement(auth_success, self.ns('attributes'))
                 for name, value in attributes.items():
                     attr = etree.SubElement(attribute_set, self.ns(name))
-                    attr.text = value
+                    attr.text = force_text(value)
             if pgt:
                 proxy_granting_ticket = etree.SubElement(auth_success, self.ns('proxyGrantingTicket'))
                 proxy_granting_ticket.text = pgt.iou
