@@ -448,17 +448,7 @@ class ServiceValidateViewTests(TestCase):
         response = ServiceValidateView.as_view()(request)
         self.assertContains(response, 'INVALID_SERVICE')
 
-    @override_settings(MAMA_CAS_USER_ATTRIBUTES={'email': 'email'})
-    def test_service_validate_view_user_attributes(self):
-        """
-        When ``MAMA_CAS_USER_ATTRIBUTES`` is defined, the validation
-        success should include the custom attribute block.
-        """
-        request = self.rf.get(reverse('cas_service_validate'), {'service': self.url, 'ticket': self.st.ticket})
-        response = ServiceValidateView.as_view()(request)
-        self.assertContains(response, 'attributes')
-
-    @override_settings(MAMA_CAS_ATTRIBUTE_CALLBACKS=('mama_cas.tests.callback.test_callback',))
+    @override_settings(MAMA_CAS_ATTRIBUTE_CALLBACKS=('mama_cas.callbacks.user_name_attributes',))
     def test_service_validate_view_attribute_callbacks(self):
         """
         When a custom callback is defined, a validation success should
@@ -572,16 +562,6 @@ class ProxyValidateViewTests(TestCase):
         self.assertContains(response, 'authenticationSuccess')
         self.assertNotContains(response, 'proxyGrantingTicket')
 
-    @override_settings(MAMA_CAS_USER_ATTRIBUTES={'email': 'email'})
-    def test_proxy_validate_view_user_attributes(self):
-        """
-        When ``MAMA_CAS_USER_ATTRIBUTES`` is defined, the validation
-        success should include the custom attribute block.
-        """
-        request = self.rf.get(reverse('cas_proxy_validate'), {'service': self.url, 'ticket': self.pt.ticket})
-        response = ProxyValidateView.as_view()(request)
-        self.assertContains(response, 'attributes')
-
     @override_settings(MAMA_CAS_VALID_SERVICES=('^[^\.]+\.example\.net',))
     def test_proxy_validate_view_invalid_service_url(self):
         """
